/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.security.sso.token.events;

import java.io.IOException;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

/**
 * Defines the public interface for logout behavior.
 *
 * <p>
 * Custom <code>LogoutProcessor</code> classes can override these default
 * implementations:
 * </p>
 *
 * <ul>
 * <li>
 * {@link
 * com.liferay.portal.security.sso.token.internal.events.CookieLogoutProcessor}
 * </li>
 * <li>
 * {@link
 * com.liferay.portal.security.sso.token.internal.events.RedirectLogoutProcessor
 * }
 * </li>
 * </ul>
 *
 * @author Michael C. Han
 */
public interface LogoutProcessor {

	public LogoutProcessorType getLogoutProcessorType();

	public void logout(
			HttpServletRequest request, HttpServletResponse response,
			String... parameters)
		throws IOException;

}