/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.portal.security.sso.token.security.auth;

import javax.servlet.http.HttpServletRequest;

/**
 * Defines the public interface for authentication token location
 * implementations.
 *
 * <p>
 * Custom <code>TokenRetriever</code> classes can override these default
 * implementations:
 * </p>
 *
 * <ul>
 * <li>
 * {@link
 * com.liferay.portal.security.sso.token.internal.security.auth.RequestTokenRetriever}
 * </li>
 * <li>
 * {@link com.liferay.portal.security.sso.token.internal.security.auth.Request
 * HeaderTokenRetriever}
 * </li>
 * <li>
 * {@link
 * com.liferay.portal.security.sso.token.internal.security.auth.CookieTokenRetriever}
 * </li>
 * <li>
 * {@link
 * com.liferay.portal.security.sso.token.internal.security.auth.SessionTokenRetriever}
 * </li>
 * </ul>
 *
 * @author Michael C. Han
 */
public interface TokenRetriever {

	public String getLoginToken(
		HttpServletRequest request, String userTokenName);

	public TokenLocation getTokenLocation();

}